@@ -6,8 +6,8 @@ use strict;
 
 use vars qw(@ISA $VERSION $CLASS *qv);
 
-$VERSION = "0.59_05";
-$VERSION = eval($VERSION);
+$VERSION = "0.67_03";
+$VERSION = eval $VERSION;
 
 $CLASS = 'version';
 
@@ -25,12 +25,14 @@ else { # use XS module
 
 # Preloaded methods go here.
 sub import {
-    my ($class, @args) = @_;
+    my ($class) = @_;
     my $callpkg = caller();
     no strict 'refs';
     
     *{$callpkg."::qv"} = 
-	    sub {return bless version::qv(shift), $class };
+	    sub {return bless version::qv(shift), $class }
+	unless defined(&{"$callpkg\::qv"});
+
 }
 
 1;
