@@ -3,9 +3,9 @@ package version::vpp;
 use strict;
 
 use Scalar::Util;
+use locale;
 use vars qw ($VERSION @ISA @REGEXS);
-$VERSION     = "0.59_05";
-$VERSION     = eval $VERSION;
+$VERSION = "0.67_03"; $VERSION = eval $VERSION;
 
 push @REGEXS, qr/
 	^v?	# optional leading 'v'
@@ -15,7 +15,6 @@ push @REGEXS, qr/
 	/x;
 
 use overload (
-    '+0'   => \&numify,
     '""'   => \&stringify,
     'cmp'  => \&vcmp,
     '<=>'  => \&vcmp,
@@ -25,28 +24,43 @@ sub new
 {
 	my ($class, $value) = @_;
 	my $self = bless ({}, ref ($class) || $class);
+	require POSIX;
+	my $currlocale = POSIX::setlocale(&POSIX::LC_ALL);
+	my $radix_comma = ( POSIX::localeconv()->{decimal_point} eq ',' );
+
+	POSIX::setlocale(&POSIX::LC_ALL, 'C') if $radix_comma;
+
+	if ( not defined $value or $value =~ /^undef$/ ) {
+	    # RT #19517 - special case for undef comparison
+	    # or someone forgot to pass a value
+	    push @{$self->{version}}, 0;
+	    return ($self);
+	}
 
 	if ( $#_ == 2 ) { # must be CVS-style
 	    $value = 'v'.$_[2];
 	}
 
-	my $eval = eval 'Scalar::Util::isvstring($value)';
-	if ( !$@ and $eval ) {
-	    $value = sprintf("v%vd",$value);
-	}
-
-	# may be a non-magic v-string
-	if ( $] >= 5.006_002 && $] < 5.008_001
-		&& length($value) >= 3 && $value !~ /[._]/ ) {
-	    $DB::single = 1;
+	# may be a v-string
+	if ( $] >= 5.006_002 && length($value) >= 3 && $value !~ /[._]/ ) {
 	    my $tvalue = sprintf("%vd",$value);
 	    if ( $tvalue =~ /^\d+\.\d+\.\d+$/ ) {
-		# must be a non-magic v-string
+		# must be a v-string
 		$value = $tvalue;
 	    }
 	}
-	    
+
+	# exponential notation
+	if ( $value =~ /\d+e-?\d+/ ) {
+	    $value = sprintf("%.9f",$value);
+	    $value =~ s/(0+)$//;
+	}
 	
+	# if the original locale used commas for decimal points, we
+	# need to force the PV to be regenerated, since just changing
+	# the locale isn't sufficient (use harmless math operation)
+	$value += 0 if $radix_comma;
+
 	# This is not very efficient, but it is morally equivalent
 	# to the XS code (as that is the reference implementation).
 	# See vutil/vutil.c for details
@@ -194,16 +208,13 @@ sub new
 	    }
 	}
 
-	if ( not exists $self->{version} ) {
-	    # oops, someone forgot to pass a value (shouldn't happen)
-	    push @{$self->{version}}, 0;
-	}
-
 	if ( substr($value,$pos) ) { # any remaining text
 	    warn "Version string '$value' contains invalid data; ".
 	         "ignoring: '".substr($value,$pos)."'";
 	}
 
+	POSIX::setlocale(&POSIX::LC_ALL, $currlocale) if $radix_comma;
+
 	return ($self);
 }
 
@@ -371,11 +382,6 @@ sub is_alpha {
 sub qv {
     my ($value) = @_;
 
-    if ( $value =~ /\d+e-?\d+/ ) { # exponential notation
-	$value = sprintf("%.9f",$value);
-	$value =~ s/(0+)//;
-    }
-
     my $eval = eval 'Scalar::Util::isvstring($value)';
     if ( !$@ and $eval ) {
 	$value = sprintf("v%vd",$value);
@@ -405,10 +411,7 @@ sub _verify {
     *UNIVERSAL::VERSION = sub {
 	my ($obj, $req) = @_;
 	my $class = ref($obj) || $obj;
-	if ( $req =~ /\d+e-?\d+/ ) { # exponential notation
-	    $req = sprintf("%.9f",$req);
-	    $req =~ s/(0+)$//;
-	}
+
 	no strict 'refs';
 	eval "require $class" unless %{"$class\::"}; # already existing
 	die "$class defines neither package nor VERSION--version check failed"
